@@ -1,7 +1,9 @@
 package Mite::App::Command;
-use Mite::MyMoo;
+use Mite::Miteception;
 extends qw(App::Cmd::Command);
 
+##-
+
 sub opt_spec {
     my ($class, $app) = (shift, @_);
 
