@@ -1,7 +1,9 @@
 package Mite::App::Command::clean;
-use Mite::MyMoo;
+use Mite::Miteception;
 extends qw(Mite::App::Command);
 
+##-
+
 sub abstract {
     return "Remove compiled mite files";
 }
