@@ -1,7 +1,9 @@
 package Mite::App::Command::compile;
-use Mite::MyMoo;
+use Mite::Miteception;
 extends qw(Mite::App::Command);
 
+##-
+
 sub abstract {
     return "Make your code ready to run";
 }
