@@ -1,7 +1,9 @@
 package Mite::App::Command::init;
-use Mite::MyMoo;
+use Mite::Miteception;
 extends qw(Mite::App::Command);
 
+##-
+
 sub usage_desc {
     return "%c init %o <project name>";
 }
