@@ -1,5 +1,5 @@
 package Mite::Class;
-use Mite::MyMoo;
+use Mite::Miteception;
 
 use Path::Tiny;
 use mro;
@@ -11,12 +11,15 @@ has attributes =>
 
 # Super classes as class names
 has extends =>
-  is            => rw,
+  is            => 'bare',
+  accessor      => 'superclasses',
   isa           => ArrayRef[Str],
   default       => sub { [] },
   trigger       => sub {
       my $self = shift;
 
+      return if !$self->name; # called from constructor
+
       # Set up our @ISA so we can use mro to calculate the class hierarchy
       $self->_set_isa;
 
@@ -24,7 +27,7 @@ has extends =>
       $self->_clear_parents;
   };
 
-# Super classes as Mite::Classes populated from $self->extends
+# Super classes as Mite::Classes populated from $self->superclasses
 has parents =>
   is            => ro,
   isa           => ArrayRef[InstanceOf['Mite::Class']],
@@ -42,7 +45,15 @@ has source =>
   is            => rw,
   isa           => InstanceOf['Mite::Source'],
   # avoid a circular dep with Mite::Source
-  weak_ref      => true;
+  weak_ref      => false;
+
+##-
+
+sub BUILD {
+    my $self = shift;
+    $self->_trigger_extends( $self->superclasses )
+        if $self->can('_trigger_extends');
+}
 
 sub project {
     my $self = shift;
@@ -63,7 +74,7 @@ sub _set_isa {
 
     mro::set_mro($name, "c3");
     no strict 'refs';
-    @{$name.'::ISA'} = @{$self->extends};
+    @{$name.'::ISA'} = @{$self->superclasses};
 
     return;
 }
@@ -88,7 +99,7 @@ sub linear_parents {
 
     my $project = $self->project;
 
-    return map { $project->class($_) } $self->linear_isa;
+    return grep defined, map { $project->class($_) } $self->linear_isa;
 }
 
 sub chained_attributes {
@@ -121,7 +132,7 @@ sub parents_attributes {
 sub _build_parents {
     my $self = shift;
 
-    my $extends = $self->extends;
+    my $extends = $self->superclasses;
     return [] if !@$extends;
 
     # Load each parent and store its Mite::Class
@@ -221,7 +232,7 @@ CODE
 sub _compile_extends {
     my $self = shift;
 
-    my $extends = $self->extends;
+    my $extends = $self->superclasses;
     return '' unless @$extends;
 
     my $source = $self->source;
@@ -253,6 +264,7 @@ sub _compile_bless {
 
 sub _compile_strict_constructor {
     my ( $self, $classvar, $selfvar, $argvar, $metavar ) = @_;
+    local $Type::Tiny::AvoidCallbacks = 1;
     my $check = Enum->of( keys %{ $self->all_attributes } )->inline_check( '$_' );
 
     return sprintf 'my @unknown = grep not( %s ), keys %%{%s}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));',
