@@ -1,5 +1,5 @@
 package Mite::Compiled;
-use Mite::MyMoo;
+use Mite::Miteception;
 
 use Path::Tiny;
 
@@ -33,7 +33,7 @@ L<Mite::Source>, L<Mite::Class>, L<Mite::Project>
 
 has file =>
   is            => ro,
-  isa           => Path,
+  isa           => Path->no_coercions->plus_coercions(Str, 'Path::Tiny::path($_)'),
   coerce        => true,
   lazy          => true,
   default       => sub {
@@ -48,6 +48,8 @@ has source =>
   weak_ref      => true,
   required      => true;
 
+##-
+
 sub compile {
     my $self = shift;
 
