@@ -1,5 +1,7 @@
 package Mite::MakeMaker;
-use Mite::MyMoo;
+use Mite::Miteception;
+
+##-
 
 use File::Find;
 use autodie;
