@@ -1,18 +1,26 @@
 package Mite::Project;
-use Mite::MyMoo;
-with qw(
-    Mite::Role::HasConfig
-    Mite::Role::HasDefault
-);
-
-use Mite::Source;
-use Mite::Class;
+use Mite::Miteception;
 
 has sources =>
   is            => ro,
   isa           => HashRef[InstanceOf['Mite::Source']],
   default       => sub { {} };
 
+has config =>
+  is            => ro,
+  isa           => InstanceOf['Mite::Config'],
+  lazy          => 1,
+  default       => sub {
+      require Mite::Config;
+      state $config = Mite::Config->new;
+      return $config;
+  };
+
+##-
+
+use Mite::Source;
+use Mite::Class;
+
 sub classes {
     my $self = shift;
 
@@ -98,7 +106,7 @@ sub inject_mite_functions {
     *{ $package .'::extends' } = sub {
         my (@classes) = @_;
 
-        $class->extends(\@classes);
+        $class->superclasses(\@classes);
 
         return;
     };
@@ -277,4 +285,19 @@ sub write_default_config {
     return;
 }
 
+{
+    # Get/set the default for a class
+    my %Defaults;
+    sub default {
+        my $class = shift;
+        return $Defaults{$class} ||= $class->new;
+    }
+
+    sub set_default {
+        my ( $class, $new_default ) = ( shift, @_ );
+        $Defaults{$class} = $new_default;
+        return;
+    }
+}
+
 1;
